@@ -203,9 +203,9 @@ def has_equal_ast(state, incorrect_msg=None, code=None, exact=True, append=None)
 
 
 DEFAULT_INCORRECT_MSG = "Expected {{test_desc}}`{{sol_eval}}`, but got `{{stu_eval}}`."
-DEFAULT_ERROR_MSG = "Running {{'it' if parent['part'] else 'the higlighted expression'}} generated an error: `{{stu_str}}`."
-DEFAULT_ERROR_MSG_INV = "Running {{'it' if parent['part'] else 'the higlighted expression'}} didn't generate an error, but it should!"
-DEFAULT_UNDEFINED_NAME_MSG = "Running {{'it' if parent['part'] else 'the higlighted expression'}} should define a variable `{{name}}` without errors, but it doesn't."
+DEFAULT_ERROR_MSG = "Running {{'it' if parent['part'] else 'the highlighted expression'}} generated an error: `{{stu_str}}`."
+DEFAULT_ERROR_MSG_INV = "Running {{'it' if parent['part'] else 'the highlighted expression'}} didn't generate an error, but it should!"
+DEFAULT_UNDEFINED_NAME_MSG = "Running {{'it' if parent['part'] else 'the highlighted expression'}} should define a variable `{{name}}` without errors, but it doesn't."
 DEFAULT_INCORRECT_NAME_MSG = (
     "Are you sure you assigned the correct value to `{{name}}`?"
 )
@@ -349,12 +349,15 @@ def has_expr(
         if isinstance(eval_sol, str):
             fmt_kwargs["sol_eval"] = '\'{}\''.format(fmt_kwargs["sol_eval"])
 
+    # reformat student evaluation string if it is too long
+    fmt_kwargs["stu_eval"] = utils.shorten_string(fmt_kwargs["stu_eval"])
+
     # check if student or solution evaluations are too long or contain newlines
     if incorrect_msg == DEFAULT_INCORRECT_MSG and (
-        utils.unshowable_string(fmt_kwargs["stu_eval"])
-        or utils.unshowable_string(fmt_kwargs["sol_eval"])
-        or fmt_kwargs["stu_eval"] == fmt_kwargs["sol_eval"]
-    ):
+        len(fmt_kwargs["sol_eval"]) > 50 or
+        utils.has_newline(fmt_kwargs["stu_eval"]) or
+        utils.has_newline(fmt_kwargs["sol_eval"]) or
+        fmt_kwargs["stu_eval"] == fmt_kwargs["sol_eval"]):
         fmt_kwargs["stu_eval"] = None
         fmt_kwargs["sol_eval"] = None
         incorrect_msg = "Expected something different."
